@@ -48,28 +48,27 @@ class KdePlatformDependent : public QObject, public Attica::PlatformDependent
 public:
     KdePlatformDependent();
     virtual ~KdePlatformDependent();
-    virtual QList<QUrl> getDefaultProviderFiles() const;
-    virtual void addDefaultProviderFile(const QUrl& url);
-    virtual void removeDefaultProviderFile(const QUrl& url);
-    virtual void enableProvider(const QUrl& baseUrl, bool enabled) const;
-    virtual bool isEnabled(const QUrl& baseUrl) const;
+    QList<QUrl> getDefaultProviderFiles() const Q_DECL_OVERRIDE;
+    void addDefaultProviderFile(const QUrl& url) Q_DECL_OVERRIDE;
+    void removeDefaultProviderFile(const QUrl& url) Q_DECL_OVERRIDE;
+    void enableProvider(const QUrl& baseUrl, bool enabled) const Q_DECL_OVERRIDE;
+    bool isEnabled(const QUrl& baseUrl) const Q_DECL_OVERRIDE;
 
-    virtual QNetworkReply* post(const QNetworkRequest& request, const QByteArray& data);
-    virtual QNetworkReply* post(const QNetworkRequest& request, QIODevice* data);
-    virtual QNetworkReply* get(const QNetworkRequest& request);
-    virtual bool saveCredentials(const QUrl& baseUrl, const QString& user, const QString& password);
-    virtual bool hasCredentials(const QUrl& baseUrl) const;
-    virtual bool loadCredentials(const QUrl& baseUrl, QString& user, QString& password);
-    virtual bool askForCredentials(const QUrl& baseUrl, QString& user, QString& password);
-    virtual QNetworkAccessManager* nam();
+    QNetworkReply* post(const QNetworkRequest& request, const QByteArray& data) Q_DECL_OVERRIDE;
+    QNetworkReply* post(const QNetworkRequest& request, QIODevice* data) Q_DECL_OVERRIDE;
+    QNetworkReply* get(const QNetworkRequest& request) Q_DECL_OVERRIDE;
+    bool saveCredentials(const QUrl& baseUrl, const QString& user, const QString& password) Q_DECL_OVERRIDE;
+    bool hasCredentials(const QUrl& baseUrl) const Q_DECL_OVERRIDE;
+    bool loadCredentials(const QUrl& baseUrl, QString& user, QString& password) Q_DECL_OVERRIDE;
+    bool askForCredentials(const QUrl& baseUrl, QString& user, QString& password) Q_DECL_OVERRIDE;
+    QNetworkAccessManager* nam() Q_DECL_OVERRIDE;
 
 private:
     bool openWallet(bool force);
     QNetworkRequest removeAuthFromRequest(const QNetworkRequest& request);
 
     KSharedConfigPtr m_config;
-    //QNetworkAccessManager m_qnam;
-    KIO::Integration::AccessManager* m_accessManager;
+    QNetworkAccessManager* m_accessManager;
     KWallet::Wallet* m_wallet;
     QHash<QString, QPair <QString, QString> > m_passwords;
 };
